@@ -114,6 +114,8 @@ sub BuildDB
 
 	$dbh = connect_db();
 
+	prepare_sql($sdbh, \%ssths, qw(create_view));
+	$ssths{create_view}->execute or die DBI->errstr;
 	prepare_sql($sdbh, \%ssths, qw(sqlports_count_ports sqlports_fullpkgpaths_by_maintainer));
 
 	if ($settings{restrict_maintainer}) {
@@ -131,6 +133,7 @@ sub BuildDB
 	# Query SQLports for all the information we need. We don't care about
 	# restrictions for now as this step basically copies sqlports. Check()
 	# will handle any restrictions instead.
+	
 	$ssths{sqlports_count_ports}->execute or die DBI->errstr;
 	$num_ports = $ssths{sqlports_count_ports}->fetchrow_array();
 
@@ -159,14 +162,49 @@ sub BuildDB
 sub BuildPort
 {
     my ($ps, $sdbh) = @_;
-    my (@ports, $ssth);
+    my (@ports, $q, $total_ports, $limit);
     my $n_port = 0;
-    my $total_ports = $sdbh->selectrow_array("SELECT COUNT(FULLPKGPATH) FROM Ports;");
 
-    $ssth = $sdbh->prepare("SELECT FULLPKGPATH, CATEGORIES, DISTNAME, DISTFILES, MASTER_SITES, MAINTAINER, COMMENT, PORTROACH, PORTROACH_COMMENT, HOMEPAGE FROM Ports");
-    $ssth->execute() or die DBI->errstr;
+    my $sths = {};
+    prepare_sql($sdbh, $sths, qw(ports_select ports_select_count
+                                 ports_restrict_maintainer ports_restrict_maintainer_count
+                                 ports_restrict_category ports_restrict_category_count
+				 ports_restrict_port  ports_restrict_port_count));
 
-    while(@ports = $ssth->fetchrow_array()) {
+    # Apply any needed restrictions.
+    if ($settings{restrict_maintainer}) {
+	$limit = "$settings{restrict_maintainer}%";
+
+	$sths->{ports_restrict_maintainer}->execute($limit) or die DBI->errstr;
+	$sths->{ports_restrict_maintainer_count}->execute($limit) or die DBI->errstr;
+
+	$total_ports = $sths->{ports_restrict_maintainer_count}->fetchrow_array();
+	$q = $sths->{ports_restrict_maintainer};
+    } elsif ($settings{restrict_category}) {
+	$limit = "$settings{restrict_category}";
+
+	$sths->{ports_restrict_category}->execute($limit) or die DBI->errstr;
+	$sths->{ports_restrict_category_count}->execute($limit) or die DBI->errstr;
+
+	$total_ports = $sths->{ports_restrict_category_count}->fetchrow_array();
+	$q = $sths->{ports_restrict_category};
+    } elsif ($settings{restrict_port}) {
+	$limit = "%$settings{restrict_port}%";
+
+	$sths->{ports_restrict_port}->execute($limit) or die DBI->errstr;
+	$sths->{ports_restrict_port_count}->execute($limit) or die DBI->errstr;
+
+	$total_ports = $sths->{ports_restrict_port_count}->fetchrow_array();
+	$q = $sths->{ports_restrict_port};
+    } else {
+	$sths->{ports_select}->execute() or die DBI->errstr;
+	$sths->{ports_select_count}->execute() or die DBI->errstr;
+
+	$total_ports = $sths->{ports_select_count}->fetchrow_array();
+	$q = $sths->{ports_select};
+    }
+
+    while(@ports = $q->fetchrow_array()) {
 	my ($fullpkgpath, $name, $category, $distname, @distfiles, $maintainer,
 	    $comment, $sufx, %pcfg, @sites, $ver, $basepkgpath, $pcfg_comment,
 	    $homepage);
@@ -182,6 +220,10 @@ sub BuildPort
 	$name     = fullpkgpathtoport($fullpkgpath);
 
 	$distname = $ports[2];
+	# get rid of version/epoch markers
+	$distname =~ s/v[0-9]+$//;
+	$distname =~ s/p[0-9]+$//;
+
 	foreach my $file (split /\s+/, $ports[3]) {
 	    $file =~ s/:[A-Za-z0-9][A-Za-z0-9\,]*$//g;
 	    push @distfiles, $file;
@@ -268,13 +310,9 @@ sub BuildPort
 				$ver = $2;
 			}
 		}
-
-		$ver = '' if ($ver eq $name);
 	}
 
-
-	print '[' . strchop($category, 15) . '] ' unless ($settings{quiet});
-	info($name, "($n_port out of $total_ports)");
+	info(1, $fullpkgpath, "($n_port/$total_ports)");
 
 	$ps->AddPort({
 	    'name'        => $name,
