@@ -117,9 +117,39 @@ sub GetFiles
 		$ua->agent(USER_AGENT);
 		$ua->timeout($settings{http_timeout});
 
-		$response = $ua->request(HTTP::Request->new(GET => $query));
+		my $request;
 
-		if (!$response->is_success || $response->status_line !~ /^2/) {
+		if ($settings{github_token}) {
+		    #$req->authorization_basic('token', $settings{github_token});
+		    my $auth_header = HTTP::Headers->new ('Authorization' => "Token $settings{github_token}");
+		    $request = HTTP::Request->new(GET => $query, $auth_header);
+		} else {
+		    $request = HTTP::Request->new(GET => $query);
+		}
+
+		$response = $ua->request($request);
+
+		if ($response->is_success) {
+		    $json = decode_json($response->decoded_content);
+
+		    my $filename = (URI->new($json->{tarball_url})->path_segments)[-1];
+		    _debug("  -> " . $filename);
+		    $filename =~ s/^v//;
+		    $projname =~ m/.*?\/(.*)/;
+
+		    # In some cases the project name (read: repository) is part of the tagname.
+		    # For example: 'heimdal-7.3.0' is the full tagname. Therefore remove the
+		    # repository name from the filename just in case.
+		    my ($account, $repo) = split('/', $projname);
+		    $filename =~ s/^${repo}-//;
+
+		    # Use '%%' as a placeholder for easier splitting in FindNewestFile().
+		    _debug("pushing: " . $repo . "%%" . $filename . ".tar.gz with projname:${projname} account:${account} repo:${repo} filename:${filename}");
+		    push(@$files, $repo . "%%" . $filename . ".tar.gz");
+		} else {
+		    if ($response->header('x-ratelimit-remaining') == 0) {
+			print STDERR ("Error: API rate limit exceeded, please set 'github token' in portroach.conf\n");
+		    }
 			_debug('GET failed for /latest: ' . $response->status_line);
 			# Project didn't do any releases, so let's try tags instead.
 			$query = 'https://api.github.com/repos/' . $projname . '/tags';
@@ -141,27 +171,7 @@ sub GetFiles
 			    _debug("  -> $tag_url");
 			    push(@$files, $tag_url);
 			}
-
-			_debug('Found ' . scalar @$files . ' files');
-			return 1;
 		}
-		$json = decode_json($response->decoded_content);
-
-		# TODO: To generate proper URLs in the frontend:
-		# If the project has done actual releases, (check the
-		# url), then look for the item with label "Source
-		# code" and use it's name field
-		#
-		# For now we take the filename part of the URI, add
-		# a recognized extension and treat it as a file.
-		{
-		    my $filename = (URI->new($json->{tarball_url})->path_segments)[-1];
-		    _debug("  -> " . $filename);
-		    $filename =~ s/^v//;
-		    $projname =~ m/.*?\/(.*)/;
-		    push(@$files, $1 . "-" . $filename . ".tar.gz");
-		}
-
 		_debug('Found ' . scalar @$files . ' files');
 	} else {
 		return 0;
