@@ -29,6 +29,7 @@ package Portroach::Util;
 
 use Portroach::Const;
 use Portroach::Config;
+use File::Path qw(make_path);
 
 require Exporter;
 
@@ -169,7 +170,7 @@ sub emptydir
 		unlink "$dir/$_" foreach readdir($dh);
 		closedir $dh;
 	} else {
-		mkdir $dir;
+		make_path($dir);
 	}
 
 	return 1;
@@ -191,7 +192,7 @@ sub isbeta
 	my ($version) = @_;
 
 	return (
-		$version =~ /^(.*)[-_.](?:$beta_regex).*$/gi
+		$version =~ /^(.*)[-_~.](?:$beta_regex).*$/gi
 			or $version =~ /^(.*)(?<=\d)(?:$beta_regex).*$/gi
 	);
 }
@@ -638,7 +639,8 @@ sub extractsuffix
 # Func: info()
 # Desc: Format arguments into message and print.
 #
-# Args: @str - Array of message parts to chop and format.
+# Args: $full - 0/1 to indicate wether to use the full width (60).
+#       @str - Array of message parts to chop and format.
 #       $msg - Message to print unformatted after other parts.
 #
 # Retn: n/a
@@ -646,16 +648,21 @@ sub extractsuffix
 
 sub info
 {
+	my $full = shift;
 	my @items = (@_);
 	my ($str, $msg);
 
+	# 60 is chosen so that "(xxxxx/xxxxx)" will fit
+	my $width = 30;
+	$width *= 2 if $full;
+
 	return if ($settings{quiet});
 
 	$msg = pop (@items);
 
 	foreach (@items) {
 		$str .= ' ' if ($str);
-		$str .= '[' . strchop($_, 30) . ']';
+		$str .= '[' . strchop($_, $width) . ']';
 	}
 
 	print "$str $msg\n";
