@@ -32,9 +32,11 @@
 			}
 		};
 
-		this.stripEmail = function(maintainer) {
-			return maintainer.replace(/\<.*?\>/g, '');
-		};
+	    this.stripEmail = function(maintainer) {
+		// For ports with multiple maintainers, fixup the display of the separator.
+		var m = maintainer.replace(/\<.*?\>/g, '');
+		return m.replace(/ ,  /, ', ');
+	    };
 	}]);
 
 	app.controller('MaintainerController', ['$http', '$scope', '$sce', function($http, $scope, $sce) {
@@ -84,12 +86,20 @@
 		};
 	}]);
 
-	app.controller('RestrictedController', ['$http', function($http) {
+    	app.controller('RestrictedController', ['$http', '$scope', function($http, $scope) {
 		var restricted = this;
 		restricted.ports = [];
 
-		$http.get('./json/restricted.json').success(function(data) {
-			restricted.ports = data;
+		$scope.loading = true;
+
+		$scope.$watch("restricted", function(){
+			$http.get('./json/restricted.json').success(function(data) {
+				restricted.ports = data;
+			        $scope.loading = false;
+			}).error(function(e) {
+			    document.write("Could not retrieve JSON for restricted.json");
+			    $scope.loading = false;
+			});
 		});
 	}]);
 })();
